@@ -7,7 +7,9 @@ from django.utils.encoding import python_2_unicode_compatible
 from discussions.managers import (DiscussionManager, RecipientManager,
                                   MessageManager)
 
-from ..utils import tznow, get_model_string
+from django.utils.timezone import now as tznow
+
+from ..utils import get_model_string
 
 from model_utils import Choices
 
@@ -15,6 +17,7 @@ from model_utils import Choices
 AUTH_USER_MODEL = getattr(settings, 'AUTH_USER_MODEL', 'auth.User')
 
 
+@python_2_unicode_compatible
 class Recipient(models.Model):
     """
     Intermediate model to allow per recipient marking as
@@ -58,7 +61,7 @@ class Recipient(models.Model):
         app_label = 'discussions'
         abstract = True
 
-    def __unicode__(self):
+    def __str__(self):
         return (_('%(discussion)s')
                 % {'discussion': self.discussion})
 
@@ -147,13 +150,11 @@ class Discussion(models.Model):
         return self.subject
 
     def update_counters(self, commit=True):
-        from ..compat import update_fields
-
         self.recipients_count = self.recipients.count()
         self.messages_count = self.messages.count()
 
         if commit:
-            update_fields(self, fields=('recipients_count', 'messages_count'))
+            self.save(update_fields=('recipients_count', 'messages_count'))
 
     def save_recipients(self, to_user_list):
         from . import Recipient
