@@ -40,10 +40,10 @@ class CommaSeperatedFieldTests(TestCase):
              'error': ('users', [u'The following usernames are incorrect: foo.'])},
             # Multiple invalid usernames
             {'data': {'users': 'foo, bar'},
-             'error': ('users', [u'The following usernames are incorrect: foo, bar.'])},
+             'error': ('users', [u'The following usernames are incorrect: bar, foo.'])},
             # Valid and invalid
             {'data': {'users': 'foo, thoas, bar'},
-             'error': ('users', [u'The following usernames are incorrect: foo, bar.'])},
+             'error': ('users', [u'The following usernames are incorrect: bar, foo.'])},
             # Extra whitespace
             {'data': {'users': 'foo,    thoas  '},
              'error': ('users', [u'The following usernames are incorrect: foo.'])},
@@ -51,6 +51,6 @@ class CommaSeperatedFieldTests(TestCase):
         ]
         for invalid_dict in invalid_data_dicts:
             form = CommaSeparatedTestForm(data=invalid_dict['data'])
-            self.failIf(form.is_valid())
+            assert form.is_valid() is False
             self.assertEqual(form.errors[invalid_dict['error'][0]],
                              invalid_dict['error'][1])
