@@ -1,3 +1,5 @@
+from __future__ import unicode_literals
+
 from django.test import TestCase
 
 from ..models import Message, Recipient
@@ -11,8 +13,8 @@ class MessageModelTests(TestCase):
         """ Test the human representation of a message """
         message = Message.objects.get(pk=1)
         truncated_body = truncate_words(message.body, 10)
-        self.failUnlessEqual(message.__unicode__(),
-                             truncated_body)
+        self.assertEqual('%s' % message,
+                         truncated_body)
 
 
 class MessageRecipientModelTest(TestCase):
@@ -22,10 +24,10 @@ class MessageRecipientModelTest(TestCase):
         """ Test the human representation of a recipient """
         recipient = Recipient.objects.get(pk=1)
 
-        valid_unicode = '%s' % (recipient.discussion)
+        valid_unicode = '%s' % recipient.discussion
 
-        self.failUnlessEqual(recipient.__unicode__(),
-                             valid_unicode)
+        self.assertEqual('%s' % recipient,
+                         valid_unicode)
 
     def test_new(self):
         """ Test if the message that is new is correct """
