@@ -1,18 +1,13 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
+import six
+
 from collections import defaultdict
 
+from importlib import import_module
+
 from django.core import exceptions
 from django.conf import settings
-from django.utils.importlib import import_module
-from django.db.models import get_model
-
-try:
-    from django.utils.timezone import timedelta
-    from django.utils.timezone import now as tznow
-except ImportError:
-    import datetime
-    from datetime import timedelta  # NOQA
-    tznow = datetime.datetime.now  # NOQA
+from django.apps import apps
 
 from . import settings as defaults
 
@@ -30,7 +25,7 @@ def load_class(class_path, setting_name=None):
     The setting_name parameter is only there for pretty error output, and
     therefore is optional
     """
-    if not isinstance(class_path, basestring):
+    if not isinstance(class_path, six.string_types):
         try:
             class_path, app_label = class_path
         except:
@@ -53,7 +48,7 @@ def load_class(class_path, setting_name=None):
 
     try:
         mod = import_module(class_module)
-    except ImportError, e:
+    except ImportError as e:
         if setting_name:
             txt = 'Error importing backend %s: "%s". Check your %s setting' % (
                 class_module, e, setting_name)
@@ -87,7 +82,7 @@ def get_profile_model():
     if (not hasattr(settings, 'AUTH_PROFILE_MODULE')) or (not settings.AUTH_PROFILE_MODULE):
         return None
 
-    return get_model(*settings.AUTH_PROFILE_MODULE.split('.'))
+    return apps.get_model(*settings.AUTH_PROFILE_MODULE.split('.'))
 
 
 def queryset_to_dict(qs, key='pk', singular=True):
